@@ -319,9 +319,9 @@ OsiPresolve::presolvedModel(OsiSolverInterface & si,
       memcpy(originalRow_,prob.originalRow_,nrowsNow*sizeof(int));
       delete [] prob.originalRow_;
       prob.originalRow_=NULL;
-
-      // now clean up integer variables.  This can modify original
-      {
+      /* now clean up integer variables.  This can modify original
+	 Don't do if dupcol added columns together */
+      if ((prob.presolveOptions_&0x80000000)==0) {
 	int numberChanges=0;
 	const double * lower0 = originalModel_->getColLower();
 	const double * upper0 = originalModel_->getColUpper();
@@ -331,10 +331,13 @@ OsiPresolve::presolvedModel(OsiSolverInterface & si,
 	  if (!presolvedModel_->isInteger(i))
 	    continue;
 	  int iOriginal = originalColumn_[i];
-	  double lowerValue0 = lower0[iOriginal];
-	  double upperValue0 = upper0[iOriginal];
 	  double lowerValue = ceil(lower[i]-1.0e-5);
 	  double upperValue = floor(upper[i]+1.0e-5);
+	  if (lowerValue==lower[i]&&
+	      upperValue==upper[i])
+	    continue; // no point going round again
+	  double lowerValue0 = lower0[iOriginal];
+	  double upperValue0 = upper0[iOriginal];
 	  presolvedModel_->setColBounds(i,lowerValue,upperValue);
 	  if (lowerValue>upperValue) {
 	    numberChanges++;
@@ -1300,13 +1303,13 @@ CoinPrePostsolveMatrix::CoinPrePostsolveMatrix(const OsiSolverInterface * si,
   // initialize and clean up bounds
   double infinity = si->getInfinity();
   if (infinity!=COIN_DBL_MAX) {
-    for (i=0;i<ncols_in;i++) {
+    for (i=0;i<ncols;i++) {
       if (clo_[i]==-infinity)
 	clo_[i]=-COIN_DBL_MAX;
       if (cup_[i]==infinity)
 	cup_[i]=COIN_DBL_MAX;
     }
-    for (i=0;i<nrows_in;i++) {
+    for (i=0;i<nrows;i++) {
       if (rlo_[i]==-infinity)
 	rlo_[i]=-COIN_DBL_MAX;
       if (rup_[i]==infinity)
@@ -1341,7 +1344,7 @@ static bool isGapFree(const CoinPackedMatrix& matrix)
   return (! (i >= 0));
 }
 CoinPresolveMatrix::CoinPresolveMatrix(int ncols0_in,
-				       double maxmin_,
+				       double /*maxmin_*/,
 				       // end prepost members
 				       OsiSolverInterface * si,
 				       // rowrep
@@ -1528,8 +1531,8 @@ CoinPresolveMatrix::CoinPresolveMatrix(int ncols0_in,
     printf("NC: %6d\n", hincol[i]);
 #endif
 
-  presolve_make_memlists(mcstrt_, hincol_, clink_, ncols_);
-  presolve_make_memlists(mrstrt_, hinrow_, rlink_, nrows_);
+  presolve_make_memlists(/*mcstrt_,*/ hincol_, clink_, ncols_);
+  presolve_make_memlists(/*mrstrt_,*/ hinrow_, rlink_, nrows_);
 
   // this allows last col/row to expand up to bufsize-1 (22);
   // this must come after the calls to presolve_prefix
@@ -1544,9 +1547,9 @@ CoinPresolveMatrix::CoinPresolveMatrix(int ncols0_in,
 }
 
 void CoinPresolveMatrix::update_model(OsiSolverInterface * si,
-				     int nrows0,
-				     int ncols0,
-				     CoinBigIndex nelems0)
+				      int /*nrows0*/,
+				      int /*ncols0*/,
+				      CoinBigIndex /*nelems0*/)
 {
   int nels=0;
   int i;
@@ -1639,21 +1642,35 @@ CoinPostsolveMatrix::CoinPostsolveMatrix(OsiSolverInterface*  si,
   int nrows1 = nrows_ ;
 
   const CoinPackedMatrix * m = si->getMatrixByCol();
-
+#if 0
   if (! isGapFree(*m)) {
     CoinPresolveAction::throwCoinError("Matrix not gap free",
 				      "CoinPostsolveMatrix");
   }
-
+#endif
   const CoinBigIndex nelemsr = m->getNumElements();
 
-  CoinDisjointCopyN(m->getVectorStarts(), ncols1, mcstrt_);
-  CoinZeroN(mcstrt_+ncols1,ncols0_-ncols1);
-  mcstrt_[ncols_] = nelems0;	// points to end of bulk store
-  CoinDisjointCopyN(m->getVectorLengths(),ncols1,  hincol_);
-  CoinDisjointCopyN(m->getIndices(),      nelemsr, hrow_);
-  CoinDisjointCopyN(m->getElements(),     nelemsr, colels_);
-
+  if (isGapFree(*m)) {
+    CoinDisjointCopyN(m->getVectorStarts(), ncols1, mcstrt_);
+    CoinZeroN(mcstrt_+ncols1,ncols0_-ncols1);
+    mcstrt_[ncols_] = nelems0;	// points to end of bulk store
+    CoinDisjointCopyN(m->getVectorLengths(),ncols1,  hincol_);
+    CoinDisjointCopyN(m->getIndices(),      nelemsr, hrow_);
+    CoinDisjointCopyN(m->getElements(),     nelemsr, colels_);
+  }
+  else
+  {
+    CoinPackedMatrix* mm = new CoinPackedMatrix(*m);
+    if( mm->hasGaps())
+      mm->removeGaps();
+    assert(nelemsr == mm->getNumElements());
+    CoinDisjointCopyN(mm->getVectorStarts(), ncols1, mcstrt_);
+    CoinZeroN(mcstrt_+ncols1,ncols0_-ncols1);
+    mcstrt_[ncols_] = nelems0;  // points to end of bulk store
+    CoinDisjointCopyN(mm->getVectorLengths(),ncols1,  hincol_);
+    CoinDisjointCopyN(mm->getIndices(),      nelemsr, hrow_);
+    CoinDisjointCopyN(mm->getElements(),     nelemsr, colels_);
+  }
 
 # if PRESOLVE_DEBUG || PRESOLVE_CONSISTENCY
   memset(cdone_, -1, ncols0_);
